from pippt import *

# Testing title slide
app = Pippt(title='Test title slide')

# Test-1: add_title_slide
# default settings
frame1 = add_title_slide()
title ="""
Testing Title method
"""
frame1.title(title)
frame1.subtitle('Subtitle method')

# Test-2: add_title_slide
# title: font Times roman & justify left
# subtitle: font Courier & side right
frame2 = add_title_slide()
title ="""
Testing title method
justify left
"""
frame2.title(title, font='Times', justify='left')
frame2.subtitle('Subtitle: right', font='Courier', side='right')

# Test-3: add_title_slide
# title: color red4 &justify right
# subtitle: color grey35 &side left 
frame3 = add_title_slide()
title ="""
Testing title method
justify right
"""
frame3.title(title, font_color='red4', justify='right')
frame3.subtitle('Subtitle: left', font_color='grey35', side='left')

# Test-4: add_title_slide
# title: adding long title
# subtitle: adding long subtitle
frame4 = add_title_slide()
title="""
Testing title method with a long title
"""
frame4.title(title)
frame4.subtitle('Testing subtitle with a long text')


# Test-5: add_title_slide
# title: spliting a long text into two lines
frame5 = add_title_slide()
title = """
Testing title method with a long title
splitting into two lines
"""
subtitle="""
Testing subtitle method with long text
splitting and justifying it 
"""
frame5.title(title)
frame5.subtitle(subtitle, side='right', justify='right')

# Bundle the frames
app.bundle(frame1, frame2, frame3, frame4, frame5)
# Keeps the application open 
app.mainloop()



from pippt import *

# Testing slide
app = Pippt(title='Test slide')

# Test-1: add_slide
# default settings
frame1 = add_slide()
frame1.title('Testing Title method')
string="""
* Adding contents to the slide with all default settings
* Adding the contents with justify left
"""
frame1.content(string, justify='left')

# Test-2: add_slide
# title: color and align
# content: no of line and align
frame2 = add_slide()
frame2.title('Testing title align left', font_color= 'grey10', align='left')
string="""
* adding point 1
* adding point 2
* adding point 3
* adding point 4
* adding point 5
"""
frame2.content(string, align='center')

# Test-3: add_slide
# title: justify right
# image: image with default settings 
frame3 = add_slide()
frame3.title('Testing title align right', align='right')
frame3.image('image/image_1.png')

# Test-4: add_slide
# title: adding long title
# image: adjust size and align
frame4 = add_slide()
title="""
Testing title method with a long title
"""
frame4.title(title)
frame4.image('image/image_1.png', size=(500, 400), align='center')


# Test-5: add_slide
# title: adding title with split lines.
# codeblock: invoking a code file
frame5 = add_slide()
title = """
Testing title method with a long title
spliting into two lines
"""
frame5.title(title)
frame5.codeblock(path='code/code.c')


# Test-6: add_slide:
# title: adding title
# codeblock: increase the size with default value(CODE_ONLY)
frame6 = add_slide()
frame6.title('Testing title', align='center')
frame6.codeblock(path='code/code.c', size=CODE_ONLY)

# Test-7: add_slide:
# title: adding title
# codeblock: adding a code as a string type
frame7 = add_slide()
frame7.title('Test Title')
string="""
#include <stdio.h>

int main()
{
        printf("Hello world!");

        return 0;
}
"""
frame7.codeblock(code=string)


# Bundle the frames
app.bundle(frame1, frame2, frame3, frame4, frame5, frame6, frame7)
# Keeps the application open 
app.mainloop()



from pippt import *

# Testing slide
app = Pippt(title='Test split slide')

# Test-1: add_split_slide
# default settings
frame1 = add_split_slide()
frame1.title('Testing Title method')
left_string="""
* Adding line 1 of the contents in left
* Adding line 2 of the contents in left
* Adding line 3 of the contents in left
"""
frame1.content(left_string, align='left')
right_string="""
* Adding line 1 of the contents in right
* Adding line 2 of the contents in right
* Adding line 3 of the contents in right
"""
frame1.content(right_string, align='right')

# Test-2: add_split_slide
# title: color and align
# content: adding content
# image : adding image
frame2 = add_split_slide()
frame2.title('Testing title align left', font_color= 'grey10', align='left')
string="""
* adding line 1 content 
* adding line 2 content 
* adding line 3 content
"""
frame2.content(string, align='left')
frame2.image('image/image_1.png', align='right', size=(400,300))

# Test-3: add_split_slide
# title: test without title
# content: adding content on right
# image: align left
frame3 = add_split_slide()
string="""
* adding line 1 content 
* adding line 2 content 
* adding line 3 content
"""
frame3.content(string, align='right')
frame3.image('image/image_1.png', align='left', size=(400,300))


# Bundle the frames
app.bundle(frame1, frame2, frame3)
# Keeps the application open 
app.mainloop()



from tkinter import *
from pippt.add_title_slide import *
from pippt.add_slide import *
from pippt.add_split_slide import *

# default title of window
_TITLE = "Pippt"
# default number of button's for one page is 16
_BUTTONS_PER_PAGE = 16

class Pippt(Tk):
    """ Pippt class inherits the Tk class from tkinter module
    """
    total_frames = 0
    current_frame = 0
    frames = ()
    
    def __init__(self, title=_TITLE):
        """ Inheriting the tkinter class in tkinter module
        
        title: Title of the main window
        """
        Tk.__init__(self, className='Pippt')
        self.title(title)
        # Get the size of screen dynamically
        width=self.winfo_screenwidth()
        height=self.winfo_screenheight()
        self.geometry(str(width)+'x'+str(height))
        
        # Key binding for moving next or previous slides 
        self.bind('<Right>', self._next_slide)
        self.bind('<Left>', self._back_slide)
        
        # Button frame to holds slide button's for quick access of slides
        self.button_frame = Frame(self)
        self.button = []
        self.prev_button = 0
        self.curr_button = 0
        # Assigning pages to have N number of button's 
        self.page = 0
        self.total_page = 0
        # Left and right button to navigate between the pages.
        self.left_button = Button(self.button_frame, text='<', font='Bold',
                                  bg='ghost white', state=DISABLED)
        self.left_button.pack(side='left', padx=(0,10))
        self.right_button = Button(self.button_frame, text='>', font='Bold',
                                   bg='ghost white', state=DISABLED)
        self.right_button.pack(side='right', padx=(10,0))
        
        # Status label for keep tracking of slides.
        self.status = Label(self)
        
    def bundle(self, *args):
        """ This method will bundle's the frames and create's 
        list of buttons respective to frame's dynamically
        
        args : tuple of frames
        """
        self.frames = args
        self.total_frames = len(self.frames)-1
        # Button for the quick access for the slide's
        for item in range(1, len(self.frames)+1):
            # Adding 0's to the single digit
            if item in (1,2,3,4,5,6,7,8,9):
                string = '0'+ str(item)
            else:
                string = str(item)
            self.button.append(Button(self.button_frame, text=string,
                                      font='Bold', relief='sunken'))
            # Direct switching to the slide using button
            self.button[item-1].config(command=lambda val=item-1: self._switch_to(val))

        self.button[0].config(state=DISABLED)
        self._button_package()
        self.total_page = len(self.button) // _BUTTONS_PER_PAGE
        # Activate left and right button's only more than 16 slides
        if self.total_page > 0 :
            self.right_button.config(state=NORMAL, command=self._move_next_page)
            self.left_button.config(command=self._move_back_page)
        self._show_frame(self.frames[self.current_frame])

    def _button_package(self):
        """ Packing buttons according to size of frames.
        
        page: button accomdation per page is 16
        """
        self._button_unpackage()
        for item in self.button[(self.page)*_BUTTONS_PER_PAGE : (self.page+1)*_BUTTONS_PER_PAGE]:
            item.pack(side='left')
                
    def _button_unpackage(self):
        """ Unpacking buttons that are previously present
        """
        for item in self.button:
            item.pack_forget()
        
    def _move_next_page(self):
        """ Moving next page for next set of buttons
        """
        if self.total_page > self.page:
            self.page += 1
            self.left_button.config(state=NORMAL)
            if self.page == self.total_page:
                # Disabling the next page button after reaching the last page
                self.right_button.config(state=DISABLED)         
        self._button_package()

    def _move_back_page(self):
        """ Moving back page for previous set of buttons
        """
        if self.page > 0:
            self.page -= 1
            self.right_button.config(state=NORMAL)
            if self.page == 0:
                # Disabling the back page button when reaching the first page
                self.left_button.config(state=DISABLED)
        self._button_package()

    def _switch_to(self, slide_no):
        """ This method will switch to slide which is being pressed
        
        slide_no : Button which is pressed
        """
        self._remove_frame(self.frames)
        self.current_frame = slide_no
        self._show_frame(self.frames[self.current_frame])
        # storing previously and currently pressed button
        self.prev_button = self.curr_button
        self.curr_button = slide_no
        # Disable the currently pressed button until next button is pressed.
        self.button[self.curr_button].config(state=DISABLED)
        self.button[self.prev_button].config(state=NORMAL)
        
    def _next_slide(self, event):
        """ Event handler for moving next slides
        """
        self._remove_frame(self.frames)
        self.bind('<Left>', self._back_slide)
        if self.current_frame < self.total_frames:
            self.current_frame += 1
            if self.current_frame == self.total_frames:
                self.unbind('<Right>')

        # Switching pages according to the slide number
        if self.current_frame > ((self.page+1) * _BUTTONS_PER_PAGE)-1:
            self._move_next_page()
                
        self.prev_button = self.curr_button
        self.curr_button = self.current_frame
        # Disabling the currently pressed button.
        self.button[self.curr_button].config(state=DISABLED)
        if self.prev_button != self.curr_button:
            # Activating the previously pressed button
            self.button[self.prev_button].config(state=NORMAL)
        self._show_frame(self.frames[self.current_frame])
    
    def _back_slide(self, event):
        """ Event handler for moving back slides
        """
        self._remove_frame(self.frames)
        self.bind('<Right>', self._next_slide)
        if self.current_frame > 0:
            self.current_frame -= 1
            if self.current_frame == 0:
                self.unbind('<Left>')
                
        # Switching pages according the slide number          
        if self.current_frame < ((self.page) * _BUTTONS_PER_PAGE):
            self._move_back_page()
            
        self.prev_button = self.curr_button
        self.curr_button = self.current_frame
        # Disabling the currently pressed button.
        self.button[self.curr_button].config(state=DISABLED)
        if self.prev_button != self.curr_button:
            # Activating the previously pressed button
            self.button[self.prev_button].config(state=NORMAL)
        self._show_frame(self.frames[self.current_frame])
        
    def _show_frame(self, frame):
        """ show_frame will display the slide, buttons and status in the window
        
        frame : current frame object for displaying the frame
        """            
        string = str(self.current_frame+1)+' of '+str(self.total_frames+1)
        self.status.config(text=string, font='Bold')
        
        self.button_frame.pack(padx=8, side='top')
        frame.pack(padx=10, pady=5, fill='both', expand='True')
        self.status.pack(side='bottom')       

    def _remove_frame(self, frames):
        """ remove_frame will remove the frame from the root window
        
        frames : tuple of frames 
        """
        for frame in frames:
            frame.pack_forget()



import os
import sys
import shutil

options = ['--init', '--help']

def create_directory(path):
    try:
        os.makedirs(path)
    except OSError:
        print('mkdir failed, check whether directory exists')
        sys.exit()

def copy_files(source, destination, path):
    dir_, file_ = os.path.split(__file__)
    src = os.path.join(dir_,'../data', source)
    des = os.path.join(path, destination)
    shutil.copyfile(src, des)

    
def pippt_init(slide_name):
    path = os.getcwd() + '/' + slide_name
    create_directory(path + '/images')
    create_directory(path + '/code')
    copy_files('image.dat', 'image.png', path + '/images')
    copy_files('code.dat', 'code.c', path + '/code')
    copy_files('sample.dat', slide_name + '.py', path)
    
def pippt_help():
    print('Usage: pi-ppt [OPTIONS] <slide_name>')
    print('')
    print('  pi-ppt: A simple presentation module')
    print('')
    print('Options:')
    print('  --init  Creates a sample format for the pi-ppt')
    print('  --help  Short description on pi-ppt module')

def pippt_usage():
    print('Error: Missing arguments for pi-ppt')
    print('')
    print('Try "pi-ppt --help" for help')
    
    
# main function
def main():
    if len(sys.argv) < 2:
        pippt_usage()
        sys.exit()

    if sys.argv[1] == options[0] and len(sys.argv) == 3:
        pippt_init(sys.argv[2])
    elif sys.argv[1] == options[1]:
        pippt_help()
    else:
        pippt_usage()
        
if __name__=='__main__':
    main()



from tkinter import *
from PIL import ImageTk, Image

# default font style and color
DEFAULT_FONT = "Ubuntu"
TITLE_FONT_COLOR = "steel blue"
CONTENT_FONT_COLOR = "grey25"
# default align and justify
ALIGN = "left"
JUSTIFY = "center"
# default image and codeblock size
IMAGE_SIZE = (350, 350)
CODE_SIZE  = (1000, 300)
# Additional size constant for image and codeblock
IMAGE_ONLY = (500, 500)
CODE_ONLY  = (900, 480)

class add_slide(Frame):
    """ add_slide: Normal slide
    
    - title()
    - content()
    - image()
    - codeblock()
    """
    
    def __init__(self):
        """ Inherit the LabelFrames class in Tkinter module
        """
        LabelFrame.__init__(self, bg='white')
        self.width = self.winfo_screenwidth()
        
        self.columnconfigure(0, weight=1)
        self.columnconfigure(1, weight=0)
        self.columnconfigure(2, weight=1)
        self.row, self.col = 2, 0
        
        self.label = Label(self, height=4, bg='white')
        self.label.grid(row=0, column=self.col,
                        padx=25, pady=(25,0))
        self.line = Canvas(self, height=5, bg=TITLE_FONT_COLOR)
        self.line.grid(row=1, column=self.col, columnspan=3,
                       padx=10, pady=(5,10), sticky=W+E)

        
    def title(self, string, font = DEFAULT_FONT,
              font_color = TITLE_FONT_COLOR, align = ALIGN):
        """ Title for the slide
        
        string    : Title string
        font      : Title font style
        font_color: Title font color
        align     : Title placement side
        """
        ht, side = 0, W
        # Stripping the line char before and after in string
        string = string.lstrip('\n')
        string = string.rstrip('\n')
        # Adding height according to lines of string
        if '\n' in string:
            ht=string.count('\n')
            
        # Alignment changes for the grid
        if   align == 'left':
            self.col, span, side = 0, 1, W
        elif align == 'right':
            self.col, span, side = 2, 1, E
        elif align == 'center':
            self.col, span, side = 0, 3, W+E

        # config the title line according to input
        self.label.config(text=string, height=ht+1, font=font+' 45 bold',
                          fg=font_color, justify=align, padx=20,
                          wraplength= self.width-100)
        self.label.grid(row=0, column=self.col, columnspan=span,
                        padx=10, pady=(25,0), sticky=side)
        # config the color of line according to title color
        self.line.config(bg=font_color)
        self.line.grid(row=1, column=0, columnspan=3,
                       padx=10, pady=(5,10), sticky=W+E)

    def content(self, string, font = DEFAULT_FONT,
                font_color = CONTENT_FONT_COLOR, align = ALIGN,
                justify = JUSTIFY):
        """ Content for the slide
        
        string    : Content string
        font      : Content font style
        font_color: Content font color
        align     : Content alignment 
        just      : Content justify side 
        """
        self.row += 1
        # Stripping line char 
        string = string.lstrip('\n')
        string = string.rstrip('\n')
        
        if   align == 'left':
            self.col, span, side = 0, 1, W
        elif align == 'right':
            self.col, span, side = 2, 1, E
        elif align == 'center':
            self.col, span, side = 0, 3, W+E

        # Content line
        label = Label(self, text=string, font=font+' 24 ', fg=font_color,
                      bg='white', justify=justify, padx=50,
                      wraplength=self.width-100)
        label.grid(row=self.row, column=self.col, columnspan=span,
                   padx=10, pady=5, sticky=side)

    def image(self, path, size = IMAGE_SIZE, align = ALIGN):
        """ Image for the slide
        
        path  : The path of the image
        size  : size of the image resolution
        align : align the image in direction
        """
        self.row += 1
        
        if   align == 'left':
            self.col, span, side = 0, 1, W
        elif align == 'right':
            self.col, span, side = 2, 1, E
        elif align == 'center':
            self.col, span, side = 0, 3, W+E
            
        # Opening image file
        load = Image.open(path)
        # Resizing it to fit inside screen
        resize = load.resize(size, Image.ANTIALIAS)
        # Loading the image
        img = ImageTk.PhotoImage(resize)
        label = Label(self, image=img, bg='white', padx=50)
        label.image = img
        label.grid(row=self.row, column=self.col, columnspan=span,
                   padx=10, pady=5, sticky=side)

    def codeblock(self, code = None, path = None, size = CODE_SIZE):
        """ Code for the slide 
        
        code  : Adding the code blocks
        path  : Path of the code
        size  : Size set to default or use CODE_ONLY to maximize
        """
        self.row += 1
        wd, ht = size

        if path != None:
            file_ = open(path, 'r')
            code = file_.read()
            
        # Creating sub frame and inserting a canvas 
        sub_frame=Frame(self, width=wd, height=ht,
                        bd=4, relief=RAISED)
        sub_frame.grid(row=self.row, column=0, columnspan=3,
                     padx=50, sticky=W)
        # canvas with sub_frame as root
        canvas=Canvas(sub_frame)
        # code_frame inside canvas 
        self.code_frame=Frame(canvas)
        # scroll x and y axis for horizontal and vertical scrolling
        scrollx=Scrollbar(sub_frame, orient="horizontal", bg='snow', width=17,
                          elementborderwidth=3, command=canvas.xview)
        canvas.configure(xscrollcommand=scrollx.set)
        scrolly=Scrollbar(sub_frame, orient="vertical", bg='snow', width=17,
                          elementborderwidth=3, command=canvas.yview)
        canvas.configure(yscrollcommand=scrolly.set)
        # packing the scrollbar
        scrollx.pack(side="bottom",fill=X)
        scrolly.pack(side="right",fill=Y)   
        canvas.pack(side="left")
        # creating window for code frame 
        canvas.create_window((0,0),window=self.code_frame,anchor='nw')
        self.code_frame.bind("<Configure>",
                   lambda e: canvas.configure(scrollregion=canvas.bbox("all"),
                                              width=wd, height=ht, bg='grey25'))
        # Adding up and down key for scrolling
        self.code_frame.focus_set()
        self.code_frame.bind("<Up>", lambda event: canvas.yview_scroll(-1, "units"))
        self.code_frame.bind("<Down>", lambda event: canvas.yview_scroll( 1, "units"))
        
        # Label the code into the code_frame
        Label(self.code_frame, text=code, font='Courier 16 bold', fg='snow',
              bg='grey25', justify='left', padx=50, pady=50).pack()



# Testing blank 50 slide for quick access of particular slide.
from pippt import *

app = Pippt()

frame_0=add_slide()
frame_1=add_slide()
frame_2=add_slide()
frame_3=add_slide()
frame_4=add_slide()
frame_5=add_slide()
frame_6=add_slide()
frame_7=add_slide()
frame_8=add_slide()
frame_9=add_slide()

frame_10=add_slide()
frame_11=add_slide()
frame_12=add_slide()
frame_13=add_slide()
frame_14=add_slide()
frame_15=add_slide()
frame_16=add_slide()
frame_17=add_slide()
frame_18=add_slide()
frame_19=add_slide()

frame_20=add_slide()
frame_21=add_slide()
frame_22=add_slide()
frame_23=add_slide()
frame_24=add_slide()
frame_25=add_slide()
frame_26=add_slide()
frame_27=add_slide()
frame_28=add_slide()
frame_29=add_slide()

frame_30=add_slide()
frame_31=add_slide()
frame_32=add_slide()
frame_33=add_slide()
frame_34=add_slide()
frame_35=add_slide()
frame_36=add_slide()
frame_37=add_slide()
frame_38=add_slide()
frame_39=add_slide()

frame_40=add_slide()
frame_41=add_slide()
frame_42=add_slide()
frame_43=add_slide()
frame_44=add_slide()
frame_45=add_slide()
frame_46=add_slide()
frame_47=add_slide()
frame_48=add_slide()
frame_49=add_slide()


app.bundle(frame_0, frame_1, frame_2, frame_3, frame_4,
           frame_5, frame_6, frame_7, frame_8, frame_9,
           frame_10, frame_11, frame_12, frame_13, frame_14,
           frame_15, frame_16, frame_17, frame_18, frame_19,
           frame_20, frame_21, frame_22, frame_23, frame_24,
           frame_25, frame_26, frame_27, frame_28, frame_29,
           frame_30, frame_31, frame_32, frame_33, frame_34,
           frame_35, frame_36, frame_37, frame_38, frame_39,
           frame_40, frame_41, frame_42, frame_43, frame_44,
           frame_45, frame_46, frame_47, frame_48, frame_49)

app.mainloop()



from tkinter import *
from PIL import ImageTk, Image

# default font style and color
DEFAULT_FONT = "Ubuntu"
TITLE_FONT_COLOR = "steel blue"
CONTENT_FONT_COLOR = "grey25"
# default align and justify
ALIGN = "left"
JUSTIFY = "center"
# default image size 
IMAGE_SIZE = (400, 400)

class add_split_slide(Frame):
    """ add_split_slide: Slide with two content space
    
    - title()
    - content()
    - image()
    """
    def __init__(self):
        """ Inherit the LabelFrames class in Tkinter module
        """
        LabelFrame.__init__(self, bg='white')
        self.width = self.winfo_screenwidth()
        
        self.columnconfigure(0, weight=1)
        self.columnconfigure(1, weight=0)
        self.columnconfigure(2, weight=1)
        self.col = 0
        self.left, self.right = 1, 1
        
        self.label = Label(self, height=4, bg='white')
        self.label.grid(row=0, column=0,
                        padx=25, pady=(25,0))
        self.line = Canvas(self, height=5, bg=TITLE_FONT_COLOR)
        self.line.grid(row=1, column=0, columnspan=3,
                       padx=10, pady=(5,10), sticky=W+E)

    def title(self, string, font = DEFAULT_FONT,
              font_color = TITLE_FONT_COLOR, align = ALIGN):
        """ Title for the slide
        
        string    : Title string
        font      : Title font style
        font_color: Title font color
        align     : Title placement side
        """
        ht, side = 0, W
        # Stripping the line char
        string = string.lstrip('\n')
        string = string.rstrip('\n')
        # Adding height according to lines of string
        if '\n' in string:
            ht=string.count('\n')
            
        # Alignment changes for the grid
        if   align == 'left':
            self.col, span, side = 0, 1, W
        elif align == 'right':
            self.col, span, side = 2, 1, E
        elif align == 'center':
            self.col, span, side = 0, 3, W+E

        # config the title line according to input
        self.label.config(text=string, height=ht+1, font=font+' 45 bold',
                          fg=font_color, justify=align, padx=20,
                          wraplength=self.width-100)
        self.label.grid(row=0, column=self.col, columnspan=span,
                        padx=10, pady=(25,0), sticky=side)
        # config the color of line according to title color
        self.line.config(bg=font_color)
        self.line.grid(row=1, column=0, columnspan=3,
                       padx=20, pady=(5,10), sticky=W+E)

    def content(self, string, align, font = DEFAULT_FONT,
                font_color = CONTENT_FONT_COLOR, justify = JUSTIFY):
        """ Content for the slide 
        
        string    : Content string 
        align     : Content placement side
        font      : Content font style
        font_color: Content font color
        justify   : Justify content
        """
        # Stripping the line char
        string = string.lstrip('\n')
        string = string.rstrip('\n')
        # Alignment of the content
        if align == 'left':
            self.left += 1
            row, self.col = self.left, 0
        elif align == 'right':
            self.right += 1
            row, self.col = self.right, 2

        label = Label(self, text=string, font=font+' 24 ',fg=font_color,
                      bg='white', justify=justify,
                      wraplength=self.width/2)
        label.grid(row=row, column=self.col, columnspan=1,
                   padx=10, pady=10)

    def image(self, path, align, size = IMAGE_SIZE):
        """ Image for the slide
        
        path  : The path of the image
        align : align the image in direction
        size  : size of the image resolution
        """
        # Alignment of the content
        if align == 'left':
            self.left += 1
            row, self.col = self.left, 0
        elif align == 'right':
            self.right += 1
            row, self.col = self.right, 2
            
        # Opening image file
        load = Image.open(path)
        # Resizing it to fit inside screen
        resize = load.resize(size, Image.ANTIALIAS)
        # Loading the image
        img = ImageTk.PhotoImage(resize)
        label = Label(self, image=img, bg='white')
        label.image = img
        label.grid(row=row, column=self.col, columnspan=1,
                   padx=10, pady=10)



from tkinter import *

# default font style and color
DEFAULT_FONT = 'Ubuntu'
TITLE_FONT_COLOR = 'steel blue'
CONTENT_FONT_COLOR = 'grey25'
# default align and justify 
ALIGN = 'left'
JUSTIFY = 'center'

class add_title_slide(Frame):
    """ add_title_slide: For title and subtitle only
    
    - title()
    - subtitle()
    """    
    def __init__(self):
        """ Inherit the LabelFrame class in Tkinter module
        """
        LabelFrame.__init__(self, bg='white')
        self.width = self.winfo_screenwidth()
        
    def title(self, string, font = DEFAULT_FONT,
              font_color = TITLE_FONT_COLOR, justify=JUSTIFY):
        """ Main title of the slide

        string    : Main title string 
        font      : Title font style
        font_color: Title font color
        justify   : Justify the Title
        """
        # Stripping the line char
        string = string.lstrip('\n')
        string = string.rstrip('\n')
        
        label = Label(self, text=string, font=font + ' 50 bold',
                      fg=font_color, bg='white', justify=justify,
                      wraplength=self.width-100)
        label.pack(side='top', padx=25, pady=(75,25))
        
    def subtitle(self, string, font = DEFAULT_FONT,
                 font_color = CONTENT_FONT_COLOR,
                 side = "top", justify = JUSTIFY):
        """ Subtitle of the slide
        
        string    : Subtitle of the slide
        font      : Subtitle Font style
        font_color: Subtitle Font color
        side      : side to align the subtitle
        justify   : Justify the subtitle
        """
        # Stripping the line char
        string = string.lstrip('\n')
        string = string.rstrip('\n')
        
        label = Label(self, text=string, font=font + ' 28 bold',
                      fg=font_color, bg='white', justify=justify,
                      wraplength=self.width-100)
        label.pack(side=side, padx=25, pady=(25,75))



from setuptools import setup
from os import path

here = path.abspath(path.dirname(__file__))
with open(path.join(here, 'README.md'), 'r') as f:
    long_description = f.read()

setup(
    name='pippt',
    version='2.0.0',
    description='A simple presentation module',
    author='Pravin Raghul',
    author_email='pravinraghul@gmail.com',
    url='https://github.com/Ideas100/Pi-ppt',
    long_description=long_description,
    long_description_content_type="text/markdown",
    license='MIT',
    classifiers= [
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.8'
    ],
    packages=['pippt'],
    py_modules=['pippt.script.pippt_script'],
    package_data={'pippt': ['data/*.dat']},
    entry_points={
        'console_scripts': ['pi-ppt = pippt.script.pippt_script:main'],
    },
    install_requires=['Pillow']
)
